#!/usr/bin/python
# -*- coding: utf-8 -*-

# Hive Budy
# Copyright (c) 2008-2020 Hive Solutions Lda.
#
# This file is part of Hive Budy.
#
# Hive Budy is free software: you can redistribute it and/or modify
# it under the terms of the Apache License as published by the Apache
# Foundation, either version 2.0 of the License, or (at your option) any
# later version.
#
# Hive Budy is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# Apache License for more details.
#
# You should have received a copy of the Apache License along with
# Hive Budy. If not, see <http://www.apache.org/licenses/>.

__version__ = "1.0.0"
""" The version of the module """

__revision__ = "$LastChangedRevision$"
""" The revision number of the module """

__date__ = "$LastChangedDate$"
""" The last change date of the module """

__copyright__ = "Copyright (c) 2008-2020 Hive Solutions Lda."
""" The copyright for the module """

__license__ = "Apache License, Version 2.0"
""" The license for the module """

from . import account
from . import address
from . import bag_line
from . import bag
from . import base
from . import brand
from . import bundle_line
from . import bundle
from . import category
from . import collection
from . import color
from . import composition
from . import country
from . import currency
from . import exchange_rate
from . import group
from . import live_model
from . import measurement
from . import media
from . import order_line
from . import order
from . import product
from . import referral
from . import season
from . import section
from . import store
from . import subscription
from . import voucher
from . import wishlist_line
from . import wishlist

from .account import BudyAccount
from .address import Address
from .bag_line import BagLine
from .bag import Bag
from .base import BudyBase
from .brand import Brand
from .bundle import Bundle
from .bundle_line import BundleLine
from .category import Category
from .collection import Collection
from .color import Color
from .composition import Composition
from .country import Country
from .currency import Currency
from .exchange_rate import ExchangeRate
from .group import Group
from .live_model import LiveModel
from .measurement import Measurement
from .media import Media
from .order_line import OrderLine
from .order import Order
from .product import Product
from .referral import Referral
from .season import Season
from .section import Section
from .store import Store
from .subscription import Subscription
from .voucher import Voucher
from .wishlist_line import WishlistLine
from .wishlist import Wishlist



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Hive Budy
# Copyright (c) 2008-2020 Hive Solutions Lda.
#
# This file is part of Hive Budy.
#
# Hive Budy is free software: you can redistribute it and/or modify
# it under the terms of the Apache License as published by the Apache
# Foundation, either version 2.0 of the License, or (at your option) any
# later version.
#
# Hive Budy is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# Apache License for more details.
#
# You should have received a copy of the Apache License along with
# Hive Budy. If not, see <http://www.apache.org/licenses/>.

__author__ = "João Magalhães <joamag@hive.pt>"
""" The author(s) of the module """

__version__ = "1.0.0"
""" The version of the module """

__revision__ = "$LastChangedRevision$"
""" The revision number of the module """

__date__ = "$LastChangedDate$"
""" The last change date of the module """

__copyright__ = "Copyright (c) 2008-2020 Hive Solutions Lda."
""" The copyright for the module """

__license__ = "Apache License, Version 2.0"
""" The license for the module """

import commons
import logging
import unittest

import appier

import budy

class CurrencyTest(unittest.TestCase):

    def setUp(self):
        self.app = budy.BudyApp(level = logging.ERROR)

    def tearDown(self):
        self.app.unload()
        adapter = appier.get_adapter()
        adapter.drop_db()

    def test_basic(self):
        budy.Currency.create_s("EUR", 2)
        budy.Currency.create_s("USD", 2)

        result = budy.Currency.round(12.45678, "EUR")

        self.assertEqual(result, 12.46)
        self.assertEqual(result, commons.Decimal(12.46))

        result = budy.Currency.round(12.45678, "EUR", rounder = commons.floor)

        self.assertEqual(result, 12.45)
        self.assertEqual(result, commons.Decimal(12.45))

        result = budy.Currency.round(12.45678, "EUR", rounder = commons.ceil)

        self.assertEqual(result, 12.46)
        self.assertEqual(result, commons.Decimal(12.46))

        result = budy.Currency.round(12.45578, "EUR")

        self.assertEqual(result, 12.46)
        self.assertEqual(result, commons.Decimal(12.46))

        result = budy.Currency.round(12.45478, "EUR")

        self.assertEqual(result, 12.45)
        self.assertEqual(result, commons.Decimal(12.45))

        result = budy.Currency.round(12.45478, "EUR", rounder = commons.floor)

        self.assertEqual(result, 12.45)
        self.assertEqual(result, commons.Decimal(12.45))

        result = budy.Currency.round(12.45478, "EUR", rounder = commons.ceil)

        self.assertEqual(result, 12.46)
        self.assertEqual(result, commons.Decimal(12.46))

    def test_format(self):
        budy.Currency.create_s("EUR", 2)
        budy.Currency.create_s("USD", 2)
        budy.Currency.create_s("JPY", 0)

        result = budy.Currency.format(1200.2, "EUR")
        self.assertEqual(result, "1200.20")

        result = budy.Currency.format(1200.238, "EUR")
        self.assertEqual(result, "1200.24")

        result = budy.Currency.format(1200.2, "USD")
        self.assertEqual(result, "1200.20")

        result = budy.Currency.format(1200.238, "USD")
        self.assertEqual(result, "1200.24")

        result = budy.Currency.format(1200.2, "JPY")
        self.assertEqual(result, "1200")

        result = budy.Currency.format(1200.238, "JPY")
        self.assertEqual(result, "1200")



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Hive Budy
# Copyright (c) 2008-2020 Hive Solutions Lda.
#
# This file is part of Hive Budy.
#
# Hive Budy is free software: you can redistribute it and/or modify
# it under the terms of the Apache License as published by the Apache
# Foundation, either version 2.0 of the License, or (at your option) any
# later version.
#
# Hive Budy is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# Apache License for more details.
#
# You should have received a copy of the Apache License along with
# Hive Budy. If not, see <http://www.apache.org/licenses/>.

__author__ = "João Magalhães <joamag@hive.pt>"
""" The author(s) of the module """

__version__ = "1.0.0"
""" The version of the module """

__revision__ = "$LastChangedRevision$"
""" The revision number of the module """

__date__ = "$LastChangedDate$"
""" The last change date of the module """

__copyright__ = "Copyright (c) 2008-2020 Hive Solutions Lda."
""" The copyright for the module """

__license__ = "Apache License, Version 2.0"
""" The license for the module """

import appier
import appier_extras

from budy import bots

class BudyApp(appier.WebApp):

    def __init__(self, *args, **kwargs):
        appier.WebApp.__init__(
            self,
            name = "budy",
            parts = (
                appier_extras.AdminPart,
            ),
            *args, **kwargs
        )
        self.login_route = "base.signin"
        self.login_redirect = "base.index_store"
        self.logout_redirect = "base.signin"
        self.scheduler = bots.Scheduler(self)
        self.omni_api = None

    def start(self):
        appier.WebApp.start(self)
        self.scheduler.start()
        self.admin_part.add_operation(
            "force_scheduler", "admin.force_scheduler",
            description = "Force scheduler",
            message = "Are you really sure you want to force scheduler?",
            note = "Forcing scheduler may consume computer resources",
            level = 3
        )

    def stop(self):
        try: import easypay
        except ImportError: easypay = None
        if easypay: easypay.ShelveAPI.cleanup()
        appier.WebApp.stop(self)

    def get_omni_api(self):
        import omni
        if self.omni_api: return self.omni_api
        self.omni_api = omni.API()
        return self.omni_api

    def _version(self):
        return "0.5.1"

    def _description(self):
        return "Budy"

    def _observations(self):
        return "Simple and easy to use E-commerce engine"

if __name__ == "__main__":
    app = BudyApp()
    app.serve()
else:
    __path__ = []
